@@ -5,26 +5,24 @@ use strict;
 use Carp ();
 BEGIN           { *DEBUG = sub () {0} unless defined &DEBUG }
 use integer;
-use Pod::Escapes 1.04 ();
+use Pod::Escapes 1.03 ();
 use Pod::Simple::LinkSection ();
 use Pod::Simple::BlackBox ();
-#use utf8;
+use utf8;
 
 use vars qw(
   $VERSION @ISA
   @Known_formatting_codes  @Known_directives
   %Known_formatting_codes  %Known_directives
-  $NL
 );
 
 @ISA = ('Pod::Simple::BlackBox');
-$VERSION = '2.29_4';
+$VERSION = '2.01';
 
 @Known_formatting_codes = qw(I B C L E F S X Z); 
 %Known_formatting_codes = map(($_=>1), @Known_formatting_codes);
 @Known_directives       = qw(head1 head2 head3 head4 item over back); 
 %Known_directives       = map(($_=>'Plain'), @Known_directives);
-$NL = $/ unless defined $NL;
 
 #-----------------------------------------------------------------------------
 # Set up some constants:
@@ -39,29 +37,9 @@ BEGIN {
   unless(MANY_LINES() >= 1) {
     die "MANY_LINES is too small (", MANY_LINES(), ")!\nAborting";
   }
-  if(defined &UNICODE) { }
-  elsif($] >= 5.008)   { *UNICODE = sub() {1}  }
-  else                 { *UNICODE = sub() {''} }
 }
 if(DEBUG > 2) {
   print "# We are ", ASCII ? '' : 'not ', "in ASCII-land\n";
-  print "# We are under a Unicode-safe Perl.\n";
-}
-
-# The NO BREAK SPACE and SOFT HYHPEN are used in several submodules.
-if ($] ge 5.007_003) {  # On sufficiently modern Perls we can handle any
-                        # character set
-  $Pod::Simple::nbsp = chr utf8::unicode_to_native(0xA0);
-  $Pod::Simple::shy  = chr utf8::unicode_to_native(0xAD);
-}
-elsif (Pod::Simple::ASCII) {  # Hard code ASCII early Perl
-  $Pod::Simple::nbsp = "\xA0";
-  $Pod::Simple::shy  = "\xAD";
-}
-else { # EBCDIC on early Perl.  We know what the values are for the code
-        # pages supported then.
-  $Pod::Simple::nbsp = "\x41";
-  $Pod::Simple::shy  = "\xCA";
 }
 
 # Design note:
@@ -83,7 +61,7 @@ __PACKAGE__->_accessorize(
 
   'hide_line_numbers', # For some dumping subclasses: whether to pointedly
                        # suppress the start_line attribute
-
+                      
   'line_count',        # the current line number
   'pod_para_count',    # count of pod paragraphs seen so far
 
@@ -96,32 +74,19 @@ __PACKAGE__->_accessorize(
   'bare_output',       # For some subclasses: whether to prepend
                        #  header-code and postpend footer-code
 
-  'keep_encoding_directive',  # whether to emit =encoding
   'nix_X_codes',       # whether to ignore X<...> codes
   'merge_text',        # whether to avoid breaking a single piece of
                        #  text up into several events
 
-  'preserve_whitespace', # whether to try to keep whitespace as-is
-  'strip_verbatim_indent', # What indent to strip from verbatim
-
-  'parse_characters',  # Whether parser should expect chars rather than octets
-
  'content_seen',      # whether we've seen any real Pod content
  'errors_seen',       # TODO: document.  whether we've seen any errors (fatal or not)
 
- 'codes_in_verbatim', # for PseudoPod extensions
-
  'code_handler',      # coderef to call when a code (non-pod) line is seen
- 'cut_handler',       # ... when a =cut line is seen
- 'pod_handler',       # ... when a =pod line is seen
- 'whiteline_handler', # ... when a line with only whitespace is seen
+ 'cut_handler',       # coderef to call when a =cut line is seen
  #Called like:
  # $code_handler->($line, $self->{'line_count'}, $self) if $code_handler;
  #  $cut_handler->($line, $self->{'line_count'}, $self) if $cut_handler;
- #  $pod_handler->($line, $self->{'line_count'}, $self) if $pod_handler;
- #   $wl_handler->($line, $self->{'line_count'}, $self) if $wl_handler;
- 'parse_empty_lists', # whether to acknowledge empty =over/=back blocks
- 'raw_mode',          # to report entire raw lines instead of Pod elements
+  
 );
 
 #@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@ -130,35 +95,6 @@ sub any_errata_seen {  # good for using as an exit() value...
   return shift->{'errors_seen'} || 0;
 }
 
-# Returns the encoding only if it was recognized as being handled and set
-sub detected_encoding {
-  return shift->{'detected_encoding'};
-}
-
-sub encoding {
-  my $this = shift;
-  return $this->{'encoding'} unless @_;  # GET.
-
-  $this->_handle_encoding_line("=encoding $_[0]");
-  if ($this->{'_processed_encoding'}) {
-    delete $this->{'_processed_encoding'};
-    if(! $this->{'encoding_command_statuses'} ) {
-      DEBUG > 2 and print " CRAZY ERROR: encoding wasn't really handled?!\n";
-    } elsif( $this->{'encoding_command_statuses'}[-1] ) {
-      $this->scream( "=encoding $_[0]",
-         sprintf "Couldn't do %s: %s",
-         $this->{'encoding_command_reqs'  }[-1],
-         $this->{'encoding_command_statuses'}[-1],
-      );
-    } else {
-      DEBUG > 2 and print " (encoding successfully handled.)\n";
-    }
-    return $this->{'encoding'};
-  } else {
-    return undef;
-  }
-}
-
 #@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 # Pull in some functions that, for some reason, I expect to see here too:
 BEGIN {
@@ -197,17 +133,9 @@ sub output_string {
   $$x = '' unless defined $$x;
   DEBUG > 4 and print "# Output string set to $x ($$x)\n";
   $this->{'output_fh'} = Pod::Simple::TiedOutFH->handle_on($_[0]);
-  return
-    $this->{'output_string'} = $_[0];
-    #${ ${ $this->{'output_fh'} } };
+  return $this->{'output_string'} = ${ $this->{'output_fh'} };
 }
 
-sub abandon_output_string { $_[0]->abandon_output_fh; delete $_[0]{'output_string'} }
-sub abandon_output_fh     { $_[0]->output_fh(undef) }
-# These don't delete the string or close the FH -- they just delete our
-#  references to it/them.
-# TODO: document these
-
 #@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 
 sub new {
@@ -333,13 +261,6 @@ sub unaccept_targets {
 #
 # And now codes (not targets or directives)
 
-# XXX Probably it is an error that the digit '9' is excluded from these re's.
-# Broken for early Perls on EBCDIC
-my $xml_name_re = eval "qr/[^-.0-8:A-Z_a-z[:^ascii:]]/";
-if (! defined $xml_name_re) {
-    $xml_name_re = qr/[\x00-\x2C\x2F\x39\x3B-\x40\x5B-\x5E\x60\x7B-\x7F]/;
-}
-
 sub accept_code { shift->accept_codes(@_) } # alias
 
 sub accept_codes {  # Add some codes
@@ -347,17 +268,20 @@ sub accept_codes {  # Add some codes
   
   foreach my $new_code (@_) {
     next unless defined $new_code and length $new_code;
-    # A good-enough check that it's good as an XML Name symbol:
-    Carp::croak "\"$new_code\" isn't a valid element name"
-      if $new_code =~ $xml_name_re
-          # Characters under 0x80 that aren't legal in an XML Name.
-      or $new_code =~ m/^[-\.0-9]/s
-      or $new_code =~ m/:[-\.0-9]/s;
-          # The legal under-0x80 Name characters that
-          #  an XML Name still can't start with.
-
+    if(ASCII) {
+      # A good-enough check that it's good as an XML Name symbol:
+      Carp::croak "\"$new_code\" isn't a valid element name"
+        if $new_code =~
+          m/[\x00-\x2C\x2F\x39\x3B-\x40\x5B-\x5E\x60\x7B-\x7F]/
+            # Characters under 0x80 that aren't legal in an XML Name.
+        or $new_code =~ m/^[-\.0-9]/s
+        or $new_code =~ m/:[-\.0-9]/s;
+            # The legal under-0x80 Name characters that 
+            #  an XML Name still can't start with.
+    }
+    
     $this->{'accept_codes'}{$new_code} = $new_code;
-
+    
     # Yes, map to itself -- just so that when we
     #  see "=extend W [whatever] thatelementname", we say that W maps
     #  to whatever $this->{accept_codes}{thatelementname} is,
@@ -379,15 +303,18 @@ sub unaccept_codes { # remove some codes
   
   foreach my $new_code (@_) {
     next unless defined $new_code and length $new_code;
-    # A good-enough check that it's good as an XML Name symbol:
-    Carp::croak "\"$new_code\" isn't a valid element name"
-      if $new_code =~ $xml_name_re
-          # Characters under 0x80 that aren't legal in an XML Name.
-      or $new_code =~ m/^[-\.0-9]/s
-      or $new_code =~ m/:[-\.0-9]/s;
-          # The legal under-0x80 Name characters that
-          #  an XML Name still can't start with.
-
+    if(ASCII) {
+      # A good-enough check that it's good as an XML Name symbol:
+      Carp::croak "\"$new_code\" isn't a valid element name"
+        if $new_code =~
+          m/[\x00-\x2C\x2F\x39\x3B-\x40\x5B-\x5E\x60\x7B-\x7F]/
+            # Characters under 0x80 that aren't legal in an XML Name.
+        or $new_code =~ m/^[-\.0-9]/s
+        or $new_code =~ m/:[-\.0-9]/s;
+            # The legal under-0x80 Name characters that 
+            #  an XML Name still can't start with.
+    }
+    
     Carp::croak "But you must accept \"$new_code\" codes -- it's a builtin!"
      if grep $new_code eq $_, @Known_formatting_codes;
 
@@ -410,8 +337,7 @@ sub parse_string_document {
     next unless defined $line_group and length $line_group;
     pos($line_group) = 0;
     while($line_group =~
-      m/([^\n\r]*)(\r?\n?)/g # supports \r, \n ,\r\n
-      #m/([^\n\r]*)((?:\r?\n)?)/g
+      m/([^\n\r]*)((?:\r?\n)?)/g
     ) {
       #print(">> $1\n"),
       $self->parse_lines($1)
@@ -461,30 +387,15 @@ sub parse_file {
   # By here, $source is a FH.
 
   $self->{'source_fh'} = $source;
-
+  
   my($i, @lines);
   until( $self->{'source_dead'} ) {
     splice @lines;
-
     for($i = MANY_LINES; $i--;) {  # read those many lines at a time
-      local $/ = $NL;
       push @lines, scalar(<$source>);  # readline
       last unless defined $lines[-1];
        # but pass thru the undef, which will set source_dead to true
     }
-
-    my $at_eof = ! $lines[-1]; # keep track of the undef
-    pop @lines if $at_eof; # silence warnings
-
-    # be eol agnostic
-    s/\r\n?/\n/g for @lines;
- 
-    # make sure there are only one line elements for parse_lines
-    @lines = split(/(?<=\n)/, join('', @lines));
-
-    # push the undef back after popping it to set source_dead to true
-    push @lines, undef if $at_eof;
-
     $self->parse_lines(@lines);
   }
   delete($self->{'source_fh'}); # so it can be GC'd
@@ -504,7 +415,7 @@ sub parse_from_file {
   } elsif(ref(\$source) eq 'GLOB') { # stet
   } elsif(ref($source)           ) { # stet
   } elsif(!length $source
-     or $source eq '-' or $source =~ m/^<&(?:STDIN|0)$/i
+     or $source eq '-' or $source =~ m/^<&(STDIN|0)$/i
   ) { 
     $source = *STDIN{IO};
   }
@@ -516,8 +427,6 @@ sub parse_from_file {
      or $to eq '-' or $to =~ m/^>&?(?:STDOUT|1)$/i
   ) {
     $self->output_fh( *STDOUT{IO} );
-  } elsif($to =~ m/^>&(?:STDERR|2)$/i) {
-    $self->output_fh( *STDERR{IO} );
   } else {
     require Symbol;
     my $out_fh = Symbol::gensym();
@@ -545,7 +454,7 @@ sub whine {
   return $self->_complain_errata(@_);
 }
 
-sub scream {    # like whine, but not suppressible
+sub scream {    # like whine, but not suppressable
   #my($self,$line,$complaint) = @_;
   my $self = shift(@_);
   ++$self->{'errors_seen'};
@@ -1031,7 +940,7 @@ sub _treat_Zs {  # Nix Z<...>'s
 # possibly a man page name (like "crontab(5)" is).
 #
 
-############# The "raw" attribute that is already there.
+############# Not implemented, I guess.
 # Sixth:
 # The raw original L<...> content, before text is split on "|", "/", etc,
 # and before E<...> codes are expanded.
@@ -1053,7 +962,6 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
   # L<text|name/"sec"> or L<text|name/sec>
   # L<text|/"sec"> or L<text|/sec> or L<text|"sec">
   # L<scheme:...>
-  # L<text|scheme:...>
 
   my($self,@stack) = @_;
 
@@ -1073,89 +981,65 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
       
       
       # By here, $treelet->[$i] is definitely an L node
-      my $ell = $treelet->[$i];
-      DEBUG > 1 and print "Ogling L node $ell\n";
+      DEBUG > 1 and print "Ogling L node $treelet->[$i]\n";
         
       # bitch if it's empty
-      if(  @{$ell} == 2
-       or (@{$ell} == 3 and $ell->[2] eq '')
+      if(  @{$treelet->[$i]} == 2
+       or (@{$treelet->[$i]} == 3 and $treelet->[$i][2] eq '')
       ) {
         $self->whine( $start_line, "An empty L<>" );
         $treelet->[$i] = 'L<>';  # just make it a text node
         next;  # and move on
       }
-
-      if( (! ref $ell->[2]  && $ell->[2] =~ /\A\s/)
-        ||(! ref $ell->[-1] && $ell->[-1] =~ /\s\z/)
-      ) {
-        $self->whine( $start_line, "L<> starts or ends with whitespace" );
-      }
      
       # Catch URLs:
-
-      # there are a number of possible cases:
-      # 1) text node containing url: http://foo.com
-      #   -> [ 'http://foo.com' ]
-      # 2) text node containing url and text: foo|http://foo.com
-      #   -> [ 'foo|http://foo.com' ]
-      # 3) text node containing url start: mailto:xE<at>foo.com
-      #   -> [ 'mailto:x', [ E ... ], 'foo.com' ]
-      # 4) text node containing url start and text: foo|mailto:xE<at>foo.com
-      #   -> [ 'foo|mailto:x', [ E ... ], 'foo.com' ]
-      # 5) other nodes containing text and url start: OE<39>Malley|http://foo.com
-      #   -> [ 'O', [ E ... ], 'Malley', '|http://foo.com' ]
-      # ... etc.
-
-      # anything before the url is part of the text.
-      # anything after it is part of the url.
-      # the url text node itself may contain parts of both.
-
-      if (my ($url_index, $text_part, $url_part) =
-        # grep is no good here; we want to bail out immediately so that we can
-        # use $1, $2, etc. without having to do the match twice.
-        sub {
-          for (2..$#$ell) {
-            next if ref $ell->[$_];
-            next unless $ell->[$_] =~ m/^(?:([^|]*)\|)?(\w+:[^:\s]\S*)$/s;
-            return ($_, $1, $2);
-          }
-          return;
-        }->()
+      # URLs can, alas, contain E<...> sequences, so we can't /assume/
+      #  that this is one text node.  But it has to START with one text
+      #  node...
+      if(! ref $treelet->[$i][2] and
+        $treelet->[$i][2] =~ m/^\w+:[^:\s]\S*$/s
       ) {
-        $ell->[1]{'type'} = 'url';
-
-        my @text = @{$ell}[2..$url_index-1];
-        push @text, $text_part if defined $text_part;
-
-        my @url  = @{$ell}[$url_index+1..$#$ell];
-        unshift @url, $url_part;
-
-        unless (@text) {
-          $ell->[1]{'content-implicit'} = 'yes';
-          @text = @url;
+        $treelet->[$i][1]{'type'} = 'url';
+        $treelet->[$i][1]{'content-implicit'} = 'yes';
+        
+        if( 3 == @{ $treelet->[$i] } ) {
+          # But if it IS just one text node (most common case)
+          DEBUG > 1 and printf qq{Catching "%s as " as ho-hum L<URL> link.\n},
+            $treelet->[$i][2]
+          ;
+          $treelet->[$i][1]{'to'} = Pod::Simple::LinkSection->new(
+            $treelet->[$i][2]
+          );                   # its own treelet
+        } else {
+          # It's a URL but complex (like "L<foo:bazE<123>bar>").  Feh.
+          #$treelet->[$i][1]{'to'} = [ @{$treelet->[$i]} ];
+          #splice @{ $treelet->[$i][1]{'to'} }, 0,2;
+          #DEBUG > 1 and printf qq{Catching "%s as " as complex L<URL> link.\n},
+          #  join '~', @{$treelet->[$i][1]{'to'  }};
+          
+          $treelet->[$i][1]{'to'} = Pod::Simple::LinkSection->new(
+            $treelet->[$i]  # yes, clone the whole content as a treelet
+          );
+          $treelet->[$i][1]{'to'}[0] = ''; # set the copy's tagname to nil
+          die "SANITY FAILURE" if $treelet->[0] eq ''; # should never happen!
+          DEBUG > 1 and print
+           qq{Catching "$treelet->[$i][1]{'to'}" as a complex L<URL> link.\n};
         }
 
-        $ell->[1]{to} = Pod::Simple::LinkSection->new(
-          @url == 1
-          ? $url[0]
-          : [ '', {}, @url ],
-        );
-
-        splice @$ell, 2, $#$ell, @text;
-
-        next;
+        next; # and move on
       }
       
+      
       # Catch some very simple and/or common cases
-      if(@{$ell} == 3 and ! ref $ell->[2]) {
-        my $it = $ell->[2];
-        if($it =~ m{^[^/|]+[(][-a-zA-Z0-9]+[)]$}s) { # man sections
+      if(@{$treelet->[$i]} == 3 and ! ref $treelet->[$i][2]) {
+        my $it = $treelet->[$i][2];
+        if($it =~ m/^[-a-zA-Z0-9]+\([-a-zA-Z0-9]+\)$/s) { # man sections
           # Hopefully neither too broad nor too restrictive a RE
           DEBUG > 1 and print "Catching \"$it\" as manpage link.\n";
-          $ell->[1]{'type'} = 'man';
+          $treelet->[$i][1]{'type'} = 'man';
           # This's the only place where man links can get made.
-          $ell->[1]{'content-implicit'} = 'yes';
-          $ell->[1]{'to'  } =
+          $treelet->[$i][1]{'content-implicit'} = 'yes';
+          $treelet->[$i][1]{'to'  } =
             Pod::Simple::LinkSection->new( $it ); # treelet!
 
           next;
@@ -1164,9 +1048,9 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
           # Extremely forgiving idea of what constitutes a bare
           #  modulename link like L<Foo::Bar> or even L<Thing::1.0::Docs::Tralala>
           DEBUG > 1 and print "Catching \"$it\" as ho-hum L<Modulename> link.\n";
-          $ell->[1]{'type'} = 'pod';
-          $ell->[1]{'content-implicit'} = 'yes';
-          $ell->[1]{'to'  } =
+          $treelet->[$i][1]{'type'} = 'pod';
+          $treelet->[$i][1]{'content-implicit'} = 'yes';
+          $treelet->[$i][1]{'to'  } =
             Pod::Simple::LinkSection->new( $it ); # treelet!
           next;
         }
@@ -1182,6 +1066,7 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
       
       
       my $link_text; # set to an arrayref if found
+      my $ell = $treelet->[$i];
       my @ell_content = @$ell;
       splice @ell_content,0,2; # Knock off the 'L' and {} bits
 
@@ -1205,13 +1090,6 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
           DEBUG > 3 and
            print "     FOUND a '|' in it.  Splitting into [$1] + [$2]\n";
 
-          if ($link_text[0] =~ m{[|/]}) {
-            $self->whine(
-              $start_line,
-              "alternative text '$link_text[0]' contains non-escaped | or /"
-            );
-          }
-
           unshift @link_text, splice @ell_content, 0, $j;
             # leaving only things at J and after
           @ell_content =  grep ref($_)||length($_), @ell_content ;
@@ -1315,7 +1193,7 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
       # And the E resolver will have to deal with all our treeletty things:
 
       if(@ell_content == 1 and !ref($ell_content[0])
-         and $ell_content[0] =~ m{^[^/]+[(][-a-zA-Z0-9]+[)]$}s
+         and $ell_content[0] =~ m/^[-a-zA-Z0-9]+\([-a-zA-Z0-9]+\)$/s
       ) {
         $ell->[1]{'type'}    = 'man';
         DEBUG > 3 and print "Considering this ($ell_content[0]) a man link.\n";
@@ -1355,7 +1233,7 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
 sub _treat_Es {
   my($self,@stack) = @_;
 
-  my($i, $treelet, $content, $replacer, $charnum);
+  my($i, $treelet, $content, $replacer);
   my $start_line = $stack[0][1]{'start_line'};
 
   # A recursive algorithm implemented iteratively!  Whee!
@@ -1414,25 +1292,12 @@ sub _treat_Es {
 
       DEBUG > 1 and print "Ogling E<$content>\n";
 
-      # XXX E<>'s contents *should* be a valid char in the scope of the current
-      # =encoding directive. Defaults to iso-8859-1, I believe. Fix this in the
-      # future sometime.
-
-      $charnum  = Pod::Escapes::e2charnum($content);
-      DEBUG > 1 and print " Considering E<$content> with char ",
-        defined($charnum) ? $charnum : "undef", ".\n";
-
-      if(!defined( $charnum )) {
-        DEBUG > 1 and print "I don't know how to deal with E<$content>.\n";
+      if(defined( $replacer = Pod::Escapes::e2char($content) )) {
+        DEBUG > 1 and print "Replacing E<$content> with $replacer\n";
+      } else {
+        DEBUG > 1 and print "I don't know how to deal with E<$content>\n";
         $self->whine( $start_line, "Unknown E content in E<$content>" );
         $replacer = "E<$content>"; # better than nothing
-      } elsif($charnum >= 255 and !UNICODE) {
-        $replacer = ASCII ? "\xA4" : "?";
-        DEBUG > 1 and print "This Perl version can't handle ", 
-          "E<$content> (chr $charnum), so replacing with $replacer\n";
-      } else {
-        $replacer = Pod::Escapes::e2char($content);
-        DEBUG > 1 and print " Replacing E<$content> with $replacer\n";
       }
 
       splice(@$treelet, $i, 1, $replacer); # no need to back up $i, tho
@@ -1458,6 +1323,7 @@ sub _treat_Ss {
   return;
 }
 
+
 sub _change_S_to_nbsp { #  a recursive function
   # Sanely assumes that the top node in the excursion won't be an S node.
   my($treelet, $in_s) = @_;
@@ -1475,7 +1341,8 @@ sub _change_S_to_nbsp { #  a recursive function
         $i +=  @$to_pull_up - 1;   # Make $i skip the pulled-up stuff
       }
     } else {
-      $treelet->[$i] =~ s/\s/$Pod::Simple::nbsp/g if $in_s;
+      $treelet->[$i] =~ tr/ /\xA0/ if ASCII and $in_s;
+       # (If not in ASCIIland, we can't assume that \xA0 == nbsp.)
        
        # Note that if you apply nbsp_for_S to text, and so turn
        # "foo S<bar baz> quux" into "foo bar&#160;faz quux", you
@@ -1544,7 +1411,7 @@ sub _out {
    "\nAbout to parse source: {{\n$_[0]\n}}\n\n";
   
   
-  my $parser = ref $class && $class->isa(__PACKAGE__) ? $class : $class->new;
+  my $parser = $class->new;
   $parser->hide_line_numbers(1);
 
   my $out = '';
