@@ -3,10 +3,11 @@
 require 5;
 package Pod::Simple::TextContent;
 use strict;
+use utf8;
 use Carp ();
 use Pod::Simple ();
 use vars qw( @ISA $VERSION );
-$VERSION = '2.29_4';
+$VERSION = '2.01';
 @ISA = ('Pod::Simple');
 
 sub new {
@@ -25,8 +26,10 @@ sub _handle_element_start {
 }
 
 sub _handle_text {
-  $_[1] =~ s/$Pod::Simple::shy//g;
-  $_[1] =~ s/$Pod::Simple::nbsp/ /g;
+  if( chr(65) eq 'A' ) {     # in ASCIIworld
+    $_[1] =~ tr/\xAD//d;
+    $_[1] =~ tr/\xA0/ /;
+  }
   print {$_[0]{'output_fh'}} $_[1];
   return;
 }
@@ -66,22 +69,9 @@ This is a subclass of L<Pod::Simple> and inherits all its methods.
 
 L<Pod::Simple>, L<Pod::Simple::Text>, L<Pod::Spell>
 
-=head1 SUPPORT
-
-Questions or discussion about POD and Pod::Simple should be sent to the
-pod-people@perl.org mail list. Send an empty email to
-pod-people-subscribe@perl.org to subscribe.
-
-This module is managed in an open GitHub repository,
-L<https://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/theory/pod-simple.git> and send patches!
-
-Patches against Pod::Simple are welcome. Please send bug reports to
-<bug-pod-simple@rt.cpan.org>.
-
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -92,19 +82,7 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Pod::Simple was created by Sean M. Burke <sburke@cpan.org>.
-But don't bother him, he's retired.
-
-Pod::Simple is maintained by:
-
-=over
-
-=item * Allison Randal C<allison@perl.org>
-
-=item * Hans Dieter Pearcey C<hdp@cpan.org>
-
-=item * David E. Wheeler C<dwheeler@cpan.org>
-
-=back
+Sean M. Burke C<sburke@cpan.org>
 
 =cut
+
