@@ -3,8 +3,7 @@ use strict;
 package Pod::Simple::TiedOutFH;
 use Symbol ('gensym');
 use Carp ();
-use vars qw($VERSION );
-$VERSION = '2.29_4';
+use utf8;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
@@ -55,8 +54,6 @@ sub PRINTF {
   return 1;
 }
 
-sub FILENO { ${ $_[0] } + 100 } # just to produce SOME number
-
 sub CLOSE { 1 }
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
